@@ -106,6 +106,9 @@ class Options:
     separator: str
     """How different parts of location shortcuts are separated."""
 
+    long_separator: str
+    """How different parts of location names are separated."""
+
     languages: list[str]
     """Language codes in order of preference.
 
