@@ -309,15 +309,25 @@ class Location(dict[str, Value]):
         self._levels = self._schema.get_schema_hierarchy(self)
         self.canonicalize()
 
-    def _shortcut(self):
-        """Get string representation with shortcuts."""
+    def _shortcut(self) -> str:
+        """Get string representation with shortcuts.
+
+        Returns:
+            shortcuts of levels separated by seperator. "" if no information is saved.
+            In particular in that case no default values for top levels are shown.
+        """
         return self.options.separator.join(
             str(level.shortcut) for level in self._levels
         )
 
     @property
-    def long_name(self):
-        """Get the string representation with names."""
+    def long_name(self) -> str:
+        """Get the string representation with names.
+
+        Returns:
+            names of levels separated by long_seperator. "" if no information is saved.
+            In particular in that case no default values for top levels are shown.
+        """
         return self.options.long_separator.join(
             str(level.name) for level in self._levels
         )
@@ -386,7 +396,7 @@ class Location(dict[str, Value]):
 
     def __bool__(self):
         """True if something is saved."""
-        return bool(super())
+        return len(self) > 0
 
     def save(self):
         """Save location data to yaml file."""
